@@ -23,16 +23,11 @@
 #include <KConfigGroup>
 #include <QLocale>
 #include <QVector>
-#if KPIMTEXTEDIT_HAVE_TEXTTOSPEECH
-#include <QtTextToSpeech/QTextToSpeech>
-#endif
+#include <QTextToSpeech>
 
-namespace KPIMTextEdit {
+using namespace KPIMTextEdit;
 TextToSpeech::TextToSpeech(QObject *parent)
     : QObject(parent)
-#if KPIMTEXTEDIT_HAVE_TEXTTOSPEECH
-    , mTextToSpeech(nullptr)
-#endif
 {
     reloadSettings();
 }
@@ -43,7 +38,6 @@ TextToSpeech::~TextToSpeech()
 
 void TextToSpeech::reloadSettings()
 {
-#if KPIMTEXTEDIT_HAVE_TEXTTOSPEECH
     KConfig config(QStringLiteral("texttospeechrc"));
     KConfigGroup grp = config.group("Settings");
     const QString engineName = grp.readEntry("engine");
@@ -62,7 +56,6 @@ void TextToSpeech::reloadSettings()
     mTextToSpeech->setVolume(grp.readEntry("volume", 0));
     mTextToSpeech->setLocale(QLocale(grp.readEntry("localeName")));
     //It doesn't have api for it mTextToSpeech->setVoice(grp.readEntry("voice"));
-#endif
 }
 
 TextToSpeech *TextToSpeech::self()
@@ -73,7 +66,6 @@ TextToSpeech *TextToSpeech::self()
 
 void TextToSpeech::slotStateChanged()
 {
-#if KPIMTEXTEDIT_HAVE_TEXTTOSPEECH
     TextToSpeech::State state;
     switch (mTextToSpeech->state()) {
     case QTextToSpeech::Ready:
@@ -90,130 +82,80 @@ void TextToSpeech::slotStateChanged()
         break;
     }
     Q_EMIT stateChanged(state);
-#endif
 }
 
 bool TextToSpeech::isReady() const
 {
-#if KPIMTEXTEDIT_HAVE_TEXTTOSPEECH
     return mTextToSpeech->state() != QTextToSpeech::BackendError;
-#else
-    return false;
-#endif
 }
 
 void TextToSpeech::say(const QString &text)
 {
-#if KPIMTEXTEDIT_HAVE_TEXTTOSPEECH
     mTextToSpeech->say(text);
-#else
-    Q_UNUSED(text);
-#endif
 }
 
 void TextToSpeech::stop()
 {
-#if KPIMTEXTEDIT_HAVE_TEXTTOSPEECH
     mTextToSpeech->stop();
-#endif
 }
 
 void TextToSpeech::pause()
 {
-#if KPIMTEXTEDIT_HAVE_TEXTTOSPEECH
     mTextToSpeech->pause();
-#endif
 }
 
 void TextToSpeech::resume()
 {
-#if KPIMTEXTEDIT_HAVE_TEXTTOSPEECH
     mTextToSpeech->resume();
-#endif
 }
 
 void TextToSpeech::setRate(double rate)
 {
-#if KPIMTEXTEDIT_HAVE_TEXTTOSPEECH
     mTextToSpeech->setRate(rate);
-#else
-    Q_UNUSED(rate);
-#endif
 }
 
 void TextToSpeech::setPitch(double pitch)
 {
-#if KPIMTEXTEDIT_HAVE_TEXTTOSPEECH
     mTextToSpeech->setPitch(pitch);
-#else
-    Q_UNUSED(pitch);
-#endif
 }
 
-void TextToSpeech::setVolume(int volume)
+void TextToSpeech::setVolume(double volume)
 {
-#if KPIMTEXTEDIT_HAVE_TEXTTOSPEECH
     mTextToSpeech->setVolume(volume);
-#else
-    Q_UNUSED(volume);
-#endif
 }
 
-int TextToSpeech::volume() const
+double TextToSpeech::volume() const
 {
-#if KPIMTEXTEDIT_HAVE_TEXTTOSPEECH
     return mTextToSpeech->volume();
-#else
-    return 0;
-#endif
 }
 
 QVector<QLocale> TextToSpeech::availableLocales() const
 {
-#if KPIMTEXTEDIT_HAVE_TEXTTOSPEECH
     return mTextToSpeech->availableLocales();
-#else
-    return QVector<QLocale>();
-#endif
 }
 
 QStringList TextToSpeech::availableVoices() const
 {
     QStringList lst;
-#if KPIMTEXTEDIT_HAVE_TEXTTOSPEECH
     const QVector<QVoice> voices = mTextToSpeech->availableVoices();
     lst.reserve(voices.count());
     for (const QVoice &voice : voices) {
         lst << voice.name();
     }
-#endif
     return lst;
 }
 
 QStringList TextToSpeech::availableEngines() const
 {
-#if KPIMTEXTEDIT_HAVE_TEXTTOSPEECH
     return QTextToSpeech::availableEngines();
-#else
-    return QStringList();
-#endif
 }
 
 void TextToSpeech::setLocale(const QLocale &locale) const
 {
-#if KPIMTEXTEDIT_HAVE_TEXTTOSPEECH
     mTextToSpeech->setLocale(locale);
-#else
-    Q_UNUSED(locale);
-#endif
 }
 
 QLocale TextToSpeech::locale() const
 {
-#if KPIMTEXTEDIT_HAVE_TEXTTOSPEECH
     return mTextToSpeech->locale();
-#else
-    return QLocale();
-#endif
-}
 }
